Crate ark_models_ext

Crate ark_models_ext 

Re-exports

pub use models::*;

Modules

glv
models
scalar_mul
transmute
Zero-cost transmutation between curve points parameterized by compatible configs.
twisted_edwards
variable_base
wnaf

Structs

Affine
Affine coordinates for a point on a twisted Edwards curve, over the base field P::BaseField.
BatchMulPreprocessing
Preprocessing used internally for batch scalar multiplication via ScalarMul::batch_mul.
MontgomeryAffine
Projective
Projective implements Extended Twisted Edwards Coordinates as described in [HKCD08].

Enums

TEFlags
Flags to be encoded into the serialization. The default flags (empty) should not change the binary representation.

Traits

AffineRepr
The canonical representation of an elliptic curve group element. This should represent the affine coordinates of the point corresponding to this group element.
CurveGroup
An opaque representation of an elliptic curve group element that is suitable for efficient group arithmetic.
MontCurveConfig
Constants and convenience functions that collectively define the Montgomery model of the curve.
PrimeGroup
Represents (elements of) a group of prime order r.
ScalarMul
TECurveConfig
Constants and convenience functions that collectively define the Twisted Edwards model of the curve.
VariableBaseMSM

Functions

double_and_add
Standard double-and-add method for multiplication by a scalar for generic additive groups.
double_and_add_affine
Standard double-and-add method for multiplication by a scalar for generic affine points.