pub struct Bucket<P>where
P: SWCurveConfig,{
pub x: <P as CurveConfig>::BaseField,
pub y: <P as CurveConfig>::BaseField,
pub zz: <P as CurveConfig>::BaseField,
pub zzz: <P as CurveConfig>::BaseField,
}Expand description
Extended Jacobian coordinates for a point on an elliptic curve in short Weierstrass
form, over the base field P::BaseField.
This struct implements arithmetic via the extended Jacobian arithmetic outlined here:
https://www.hyperelliptic.org/EFD/g1p/auto-shortw-xyzz.html
Fields
x: <P as CurveConfig>::BaseFieldX / ZZ projection of the affine X
y: <P as CurveConfig>::BaseFieldY / ZZZ projection of the affine Y
zz: <P as CurveConfig>::BaseFieldBucket multiplicative inverse. Will be 0 only at infinity.
zzz: <P as CurveConfig>::BaseFieldBucket multiplicative inverse. Will be 0 only at infinity.
Implementations
Sourceimpl<P> Bucket<P>where
P: SWCurveConfig,
impl<P> Bucket<P>where
P: SWCurveConfig,
pub const ZERO: Bucket<P>
Sourcepub const fn new_unchecked(
x: <P as CurveConfig>::BaseField,
y: <P as CurveConfig>::BaseField,
zz: <P as CurveConfig>::BaseField,
zzz: <P as CurveConfig>::BaseField,
) -> Bucket<P>
pub const fn new_unchecked( x: <P as CurveConfig>::BaseField, y: <P as CurveConfig>::BaseField, zz: <P as CurveConfig>::BaseField, zzz: <P as CurveConfig>::BaseField, ) -> Bucket<P>
Constructs a new group element without checking whether the coordinates specify a point in the subgroup.
pub fn double_in_place(&mut self)