Re-exports
pub use models::*;
Modules
- glv
- models
- scalar_
mul - transmute
- Zero-cost transmutation between curve points parameterized by compatible configs.
- twisted_
edwards - variable_
base - wnaf
Structs
- Affine
- Affine coordinates for a point on a twisted Edwards curve, over the
base field
P::BaseField. - Batch
MulPreprocessing - Preprocessing used internally for batch scalar multiplication via
ScalarMul::batch_mul. - Montgomery
Affine - Projective
Projectiveimplements Extended Twisted Edwards Coordinates as described in [HKCD08].
Enums
- TEFlags
- Flags to be encoded into the serialization. The default flags (empty) should not change the binary representation.
Traits
- Affine
Repr - The canonical representation of an elliptic curve group element. This should represent the affine coordinates of the point corresponding to this group element.
- Curve
Group - An opaque representation of an elliptic curve group element that is suitable for efficient group arithmetic.
- Mont
Curve Config - Constants and convenience functions that collectively define the Montgomery model of the curve.
- Prime
Group - Represents (elements of) a group of prime order
r. - Scalar
Mul - TECurve
Config - Constants and convenience functions that collectively define the Twisted Edwards model of the curve.
- Variable
BaseMSM
Functions
- double_
and_ add - Standard double-and-add method for multiplication by a scalar for generic additive groups.
- double_
and_ add_ affine - Standard double-and-add method for multiplication by a scalar for generic affine points.